@@ -14,7 +14,7 @@ healthcheck_port () {
   process=$1
 
   # ss truncate command name to 15 characters and this behaviour
-  # cannot be diabled
+  # cannot be disabled
   if [ ${#process} -gt 15 ] ; then
     process=${process:0:15}
   fi
@@ -29,7 +29,7 @@ healthcheck_listen () {
   process=$1
 
   # ss truncate command name to 15 characters and this behaviour
-  # cannot be diabled
+  # cannot be disabled
   if [ ${#process} -gt 15 ] ; then
     process=${process:0:15}
   fi
@@ -40,6 +40,19 @@ healthcheck_listen () {
   ss -lnp | awk '{print $5,"-",$7}' | egrep ":($ports)" | grep "$process"
 }
 
+healthcheck_socket () {
+  process=$1
+  socket=$2
+
+  # lsof truncate command name to 15 characters and this behaviour
+  # cannot be disabled
+  if [ ${#process} -gt 15 ] ; then
+    process=${process:0:15}
+  fi
+  lsof -Fc -Ua $socket | grep "c$process"
+}
+
+
 get_config_val () {
   crudini --get "$1" "$2" "$3" 2> /dev/null || echo "$4"
 }
@@ -50,9 +63,13 @@ get_url_from_vhost () {
   server_name=$(awk '/ServerName/ {print $2}' $vhost_file)
   ssl_enabled=$(awk '/SSLEngine/ {print $2}' $vhost_file)
   bind_port=$(grep -h "<VirtualHost .*>" $vhost_file | sed 's/<VirtualHost .*:\(.*\)>/\1/')
+  wsgi_alias=$(awk '/WSGIScriptAlias/ {print $2}' $vhost_file)
   proto=http
   if [[ $ssl_enabled == "on" ]]; then
     proto=https
   fi
-  echo ${proto}://${server_name}:${bind_port}/
+  if [[ $wsgi_alias != "/" ]]; then
+    wsgi_alias="${wsgi_alias}/"
+  fi
+  echo ${proto}://${server_name}:${bind_port}${wsgi_alias}
 }
