@@ -91,6 +91,17 @@ class ImageUploadManager(BaseImageManager):
             self.uploaders[uploader] = ImageUploader.get_uploader(uploader)
         return self.uploaders[uploader]
 
+    def get_push_destination(self, item):
+        push_destination = item.get('push_destination')
+        if not push_destination:
+            return get_undercloud_registry()
+
+        # If set to True, use discovered undercloud registry
+        if isinstance(push_destination, bool):
+            return get_undercloud_registry()
+
+        return push_destination
+
     def upload(self):
         """Start the upload process"""
 
@@ -104,9 +115,7 @@ class ImageUploadManager(BaseImageManager):
             image_name = item.get('imagename')
             uploader = item.get('uploader', 'docker')
             pull_source = item.get('pull_source')
-            push_destination = item.get('push_destination')
-            if not push_destination:
-                push_destination = get_undercloud_registry()
+            push_destination = self.get_push_destination(item)
 
             # This updates the parsed upload_images dict with real values
             item['push_destination'] = push_destination
@@ -325,6 +334,12 @@ class DockerImageUploader(ImageUploader):
         i = DockerImageUploader._inspect(image_url.geturl(), insecure)
         return i.get('Digest')
 
+    @staticmethod
+    def _image_labels(image, insecure):
+        image_url = DockerImageUploader._image_to_url(image)
+        i = DockerImageUploader._inspect(image_url.geturl(), insecure)
+        return i.get('Labels', {}) or {}
+
     @staticmethod
     def _image_exists(image, insecure_registries):
         try:
@@ -446,6 +461,18 @@ class DockerImageUploader(ImageUploader):
         return self._discover_tag_from_inspect(i, image, tag_from_label,
                                                fallback_tag)
 
+    def filter_images_with_labels(self, images, labels):
+        images_with_labels = []
+        for image in images:
+            url = self._image_to_url(image)
+            image_labels = self._image_labels(url.geturl(),
+                                              self.is_insecure_registry(
+                                                  url.netloc))
+            if set(labels).issubset(set(image_labels)):
+                images_with_labels.append(image)
+
+        return images_with_labels
+
     def cleanup(self, local_images):
         if not local_images:
             return []
