@@ -102,8 +102,7 @@ class UpdateStackActionTest(base.TestCase):
         mock_object_client.return_value = mock_swift
 
         action = package_update.UpdateStackAction(self.timeout,
-                                                  container=self.container,
-                                                  ceph_ansible_playbook=None)
+                                                  container=self.container)
         action.run(mock_ctx)
         mock_deepupdate.assert_called_once_with(env, update_env)
 
