@@ -182,6 +182,13 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 '/latest',
                 'openshift_etcd_image': 'etcd',
                 'openshift_etcd_tag': 'latest',
+                'openshift_gluster_namespace': 'docker.io/gluster',
+                'openshift_gluster_image': 'gluster-centos',
+                'openshift_gluster_block_image': 'glusterblock-provisioner',
+                'openshift_gluster_tag': 'latest',
+                'openshift_heketi_namespace': 'docker.io/heketi',
+                'openshift_heketi_image': 'heketi',
+                'openshift_heketi_tag': 'latest',
             },
             builder.container_images_template_inputs()
         )
@@ -201,10 +208,20 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 'openshift_base_image': 'ose',
                 'openshift_cockpit_namespace': 'docker.io/openshift-cockpit',
                 'openshift_cockpit_image': 'cockpit',
-                'openshift_cockpit_tag': 'tag',
+                'openshift_cockpit_tag': 'cockpit-tag',
                 'openshift_etcd_namespace': 'registry.access.redhat.com/rhel7',
                 'openshift_etcd_image': 'openshift-etcd',
-                'openshift_etcd_tag': 'tag',
+                'openshift_etcd_tag': 'etcd-tag',
+                'openshift_gluster_namespace':
+                'registry.access.redhat.com/rhgs3',
+                'openshift_gluster_image': 'rhgs-server-rhel7',
+                'openshift_gluster_block_image':
+                'rhgs-gluster-block-prov-rhel7',
+                'openshift_gluster_tag': 'gluster-tag',
+                'openshift_heketi_namespace':
+                'registry.access.redhat.com/rhgs3',
+                'openshift_heketi_image': 'rhgs-volmanager-rhel7',
+                'openshift_heketi_tag': 'heketi-tag',
             },
             builder.container_images_template_inputs(
                 namespace='192.0.2.0:5000/tripleomaster',
@@ -220,10 +237,17 @@ class TestKollaImageBuilderTemplate(base.TestCase):
                 openshift_base_image='ose',
                 openshift_cockpit_namespace='docker.io/openshift-cockpit',
                 openshift_cockpit_image='cockpit',
-                openshift_cockpit_tag='tag',
+                openshift_cockpit_tag='cockpit-tag',
                 openshift_etcd_namespace='registry.access.redhat.com/rhel7',
                 openshift_etcd_image='openshift-etcd',
-                openshift_etcd_tag='tag',
+                openshift_etcd_tag='etcd-tag',
+                openshift_gluster_namespace='registry.access.redhat.com/rhgs3',
+                openshift_gluster_image='rhgs-server-rhel7',
+                openshift_gluster_block_image='rhgs-gluster-block-prov-rhel7',
+                openshift_gluster_tag='gluster-tag',
+                openshift_heketi_namespace='registry.access.redhat.com/rhgs3',
+                openshift_heketi_image='rhgs-volmanager-rhel7',
+                openshift_heketi_tag='heketi-tag',
             )
         )
 
@@ -509,6 +533,40 @@ class TestPrepare(base.TestCase):
             )
         )
 
+    @mock.patch('requests.get')
+    @mock.patch('tripleo_common.image.image_uploader.get_undercloud_registry')
+    def test_prepare_push_dest_discover(self, mock_gur, mock_get):
+        mock_gur.return_value = '192.0.2.0:8787'
+        self.assertEqual({
+            'container_images.yaml': [{
+                'imagename': 'docker.io/t/p-nova-api:l',
+                'push_destination': '192.0.2.0:8787',
+            }],
+            'environments/containers-default-parameters.yaml': {
+                'DockerNovaApiImage':
+                '192.0.2.0:8787/t/p-nova-api:l',
+                'DockerNovaConfigImage':
+                '192.0.2.0:8787/t/p-nova-api:l',
+                'DockerNovaMetadataConfigImage':
+                u'192.0.2.0:8787/t/p-nova-api:l',
+                'DockerNovaMetadataImage':
+                '192.0.2.0:8787/t/p-nova-api:l'
+            }},
+            kb.container_images_prepare(
+                template_file=TEMPLATE_PATH,
+                output_env_file=constants.CONTAINER_DEFAULTS_ENVIRONMENT,
+                output_images_file='container_images.yaml',
+                service_filter=['OS::TripleO::Services::NovaApi'],
+                push_destination=True,
+                mapping_args={
+                    'namespace': 'docker.io/t',
+                    'name_prefix': 'p',
+                    'name_suffix': '',
+                    'tag': 'l',
+                }
+            )
+        )
+
     @mock.patch('requests.get')
     def test_prepare_ceph(self, mock_get):
         self.assertEqual({
@@ -758,6 +816,7 @@ class TestPrepare(base.TestCase):
         }
         env = {
             'parameter_defaults': {
+                'LocalContainerRegistry': '192.0.2.1',
                 'ContainerImagePrepare': [{
                     'set': mapping_args,
                     'tag_from_label': 'foo',
@@ -766,8 +825,9 @@ class TestPrepare(base.TestCase):
                     'set': mapping_args,
                     'tag_from_label': 'bar',
                     'excludes': ['nova', 'neutron'],
-                    'push_destination': '192.0.2.1:8787',
+                    'push_destination': True,
                     'modify_role': 'add-foo-plugin',
+                    'modify_only_with_labels': ['kolla_version'],
                     'modify_vars': {'foo_version': '1.0.1'}
                 }]
             }
@@ -810,8 +870,9 @@ class TestPrepare(base.TestCase):
                 push_destination=None,
                 service_filter=None,
                 tag_from_label='foo',
-                append_tag=None,
+                append_tag=mock.ANY,
                 modify_role=None,
+                modify_only_with_labels=None,
                 modify_vars=None
             ),
             mock.call(
@@ -826,6 +887,7 @@ class TestPrepare(base.TestCase):
                 tag_from_label='bar',
                 append_tag=mock.ANY,
                 modify_role='add-foo-plugin',
+                modify_only_with_labels=['kolla_version'],
                 modify_vars={'foo_version': '1.0.1'}
             )
         ])
@@ -863,6 +925,7 @@ class TestPrepare(base.TestCase):
                     'excludes': ['nova', 'neutron'],
                     'push_destination': '192.0.2.1:8787',
                     'modify_role': 'add-foo-plugin',
+                    'modify_only_with_labels': ['kolla_version'],
                     'modify_vars': {'foo_version': '1.0.1'},
                     'modify_append_tag': 'modify-123'
                 }]
@@ -906,8 +969,9 @@ class TestPrepare(base.TestCase):
                 push_destination=None,
                 service_filter=None,
                 tag_from_label='foo',
-                append_tag=None,
+                append_tag=mock.ANY,
                 modify_role=None,
+                modify_only_with_labels=None,
                 modify_vars=None
             ),
             mock.call(
@@ -922,6 +986,7 @@ class TestPrepare(base.TestCase):
                 tag_from_label='bar',
                 append_tag=mock.ANY,
                 modify_role='add-foo-plugin',
+                modify_only_with_labels=['kolla_version'],
                 modify_vars={'foo_version': '1.0.1'}
             )
         ])
