@@ -121,13 +121,14 @@ class DriverInfo(object):
 class PrefixedDriverInfo(DriverInfo):
     def __init__(self, prefix, deprecated_mapping=None,
                  has_port=False, address_field='address',
-                 default_port=None, hardware_type=None):
+                 default_port=None, hardware_type=None,
+                 mandatory_fields=None):
         mapping = {
             'pm_addr': '%s_%s' % (prefix, address_field),
             'pm_user': '%s_username' % prefix,
             'pm_password': '%s_password' % prefix,
         }
-        mandatory_fields = list(mapping)
+        mandatory_fields = mandatory_fields or list(mapping)
 
         if has_port:
             mapping['pm_port'] = '%s_port' % prefix
@@ -263,20 +264,53 @@ class iBootDriverInfo(PrefixedDriverInfo):
         return result
 
 
+class UcsDriverInfo(DriverInfo):
+    def __init__(self):
+        mapping = {
+            'pm_addr': 'ucs_address',
+            'pm_user': 'ucs_username',
+            'pm_password': 'ucs_password',
+            'pm_service_profile': 'ucs_service_profile'
+        }
+        mandatory_fields = list(mapping)
+
+        super(UcsDriverInfo, self).__init__(
+            'ucs', mapping,
+            mandatory_fields=mandatory_fields,
+            hardware_type='cisco-ucs-managed',
+        )
+
+    def unique_id_from_fields(self, fields):
+        try:
+            return '%s:%s' % (fields['pm_addr'], fields['pm_service_profile'])
+
+        except KeyError:
+            return
+
+    def unique_id_from_node(self, node):
+        try:
+            return '%s:%s' % (node.driver_info['ucs_address'],
+                              node.driver_info['ucs_service_profile'])
+        except KeyError:
+            return
+
+
 DRIVER_INFO = {
     # production drivers
     '(ipmi|.*_ipmitool)': PrefixedDriverInfo('ipmi', has_port=True,
                                              default_port=623,
-                                             hardware_type='ipmi'),
+                                             hardware_type='ipmi',
+                                             mandatory_fields=['pm_addr']
+                                             ),
     '(idrac|.*_drac)': PrefixedDriverInfo('drac', has_port=True,
                                           hardware_type='idrac'),
     '(ilo|.*_ilo)': PrefixedDriverInfo('ilo', has_port=True,
                                        hardware_type='ilo'),
-    '(cisco\-ucs\-managed|.*_ucs)': PrefixedDriverInfo(
-        'ucs', hardware_type='cisco-ucs-managed'),
+    '(cisco\-ucs\-managed|.*_ucs)': UcsDriverInfo(),
     '(irmc|.*_irmc)': PrefixedDriverInfo('irmc', has_port=True,
                                          hardware_type='irmc'),
     'redfish': RedfishDriverInfo(),
+    'xclarity': PrefixedDriverInfo('xclarity', has_port=True),
     # test drivers
     'staging\-ovirt': oVirtDriverInfo(),
     '(staging\-iboot|.*_iboot)': iBootDriverInfo(),
@@ -349,6 +383,11 @@ def register_ironic_node(node, client):
                   for k, v in mapping.items()
                   if node.get(v) is not None}
 
+    extra = {}
+    platform = node.get('platform')
+    if platform:
+        extra = dict(tripleo_platform=platform)
+
     if 'capabilities' in node:
         caps = node['capabilities']
         if isinstance(caps, dict):
@@ -367,6 +406,8 @@ def register_ironic_node(node, client):
                   "driver_info": driver_info,
                   "resource_class": resource_class}
     create_map.update(interface_fields)
+    if extra:
+        create_map["extra"] = extra
 
     for field in ('name', 'uuid'):
         if field in node:
@@ -449,7 +490,9 @@ _NON_DRIVER_FIELDS = {'cpu': '/properties/cpus',
                                     '/driver_info/rescue_kernel'],
                       'ramdisk_id': ['/driver_info/deploy_ramdisk',
                                      '/driver_info/rescue_ramdisk'],
-                      'capabilities': '/properties/capabilities'}
+                      'capabilities': '/properties/capabilities',
+                      'platform': '/extra/tripleo_platform',
+                      }
 
 _NON_DRIVER_FIELDS.update({field: '/%s' % field
                            for field in _KNOWN_INTERFACE_FIELDS})
@@ -586,6 +629,11 @@ def validate_nodes(nodes_list):
             else:
                 names.add(node['name'])
 
+        if node.get('platform') and not node.get('arch'):
+            failures.append(
+                (index,
+                 'You have specified a platform without an architecture'))
+
         try:
             capabilities_to_dict(node.get('capabilities'))
         except (ValueError, TypeError):
